# Table of Contents

- [portal-parameterized-links](<./portal-parameterized-links.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Portal: Parameterized Links](<./Portal-Parameterized-Links.md>)
  - [Was this page helpful?](<./Portal-Parameterized-Links/Was-this-page-helpful.md>)
